==> apo-ws-client-6.00.10.4-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerDIP.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="diplome" type="{DiplomeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}DiplomeDTO" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "diplome"
})
@XmlRootElement(name = "creerDIP", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier_17102019")
public class CreerDIP {

    @XmlElement(required = true)
    protected DiplomeDTO diplome;

    /**
     * Obtient la valeur de la propriété diplome.
     * 
     * @return
     *     possible object is
     *     {@link DiplomeDTO }
     *     
     */
    public DiplomeDTO getDiplome() {
        return diplome;
    }

    /**
     * Définit la valeur de la propriété diplome.
     * 
     * @param value
     *     allowed object is
     *     {@link DiplomeDTO }
     *     
     */
    public void setDiplome(DiplomeDTO value) {
        this.diplome = value;
    }

}

==> apo-ws-client-6.00.51.1-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerDIP.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="diplome" type="{DiplomeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}DiplomeDTO" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "diplome"
})
@XmlRootElement(name = "creerDIP", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier")
public class CreerDIP {

    @XmlElement(required = true)
    protected DiplomeDTO diplome;

    /**
     * Obtient la valeur de la propriété diplome.
     * 
     * @return
     *     possible object is
     *     {@link DiplomeDTO }
     *     
     */
    public DiplomeDTO getDiplome() {
        return diplome;
    }

    /**
     * Définit la valeur de la propriété diplome.
     * 
     * @param value
     *     allowed object is
     *     {@link DiplomeDTO }
     *     
     */
    public void setDiplome(DiplomeDTO value) {
        this.diplome = value;
    }

}
